==> xfsprogs-2.6.13-i486-1.tgz: install/doinst.sh <==
( cd lib ; rm -rf libhandle.so )
( cd lib ; ln -sf libhandle.so.1 libhandle.so )
( cd lib ; rm -rf libacl.so.1 )
( cd lib ; ln -sf libacl.so.1.1.0 libacl.so.1 )
( cd lib ; rm -rf libhandle.so.1 )
( cd lib ; ln -sf libhandle.so.1.0.3 libhandle.so.1 )
( cd lib ; rm -rf libattr.so )
( cd lib ; ln -sf libattr.so.1 libattr.so )
( cd lib ; rm -rf libattr.so.1 )
( cd lib ; ln -sf libattr.so.1.1.0 libattr.so.1 )
( cd lib ; rm -rf libdm.so.0 )
( cd lib ; ln -sf libdm.so.0.0.4 libdm.so.0 )
( cd lib ; rm -rf libdm.so )
( cd lib ; ln -sf libdm.so.0 libdm.so )
( cd usr/lib ; rm -rf libhandle.so )
( cd usr/lib ; ln -sf /lib/libhandle.so.1 libhandle.so )
( cd usr/lib ; rm -rf libattr.so )
( cd usr/lib ; ln -sf /lib/libattr.so.1 libattr.so )
( cd usr/lib ; rm -rf libdm.so )
( cd usr/lib ; ln -sf /lib/libdm.so.0 libdm.so )
( cd usr/man/man2 ; rm -rf lsetxattr.2.gz )
( cd usr/man/man2 ; ln -sf setxattr.2.gz lsetxattr.2.gz )
( cd usr/man/man2 ; rm -rf lgetxattr.2.gz )
( cd usr/man/man2 ; ln -sf getxattr.2.gz lgetxattr.2.gz )
( cd usr/man/man2 ; rm -rf llistxattr.2.gz )
( cd usr/man/man2 ; ln -sf listxattr.2.gz llistxattr.2.gz )
( cd usr/man/man2 ; rm -rf flistxattr.2.gz )
( cd usr/man/man2 ; ln -sf listxattr.2.gz flistxattr.2.gz )
( cd usr/man/man2 ; rm -rf fsetxattr.2.gz )
( cd usr/man/man2 ; ln -sf setxattr.2.gz fsetxattr.2.gz )
( cd usr/man/man2 ; rm -rf fgetxattr.2.gz )
( cd usr/man/man2 ; ln -sf getxattr.2.gz fgetxattr.2.gz )
( cd usr/man/man2 ; rm -rf lremovexattr.2.gz )
( cd usr/man/man2 ; ln -sf removexattr.2.gz lremovexattr.2.gz )
( cd usr/man/man2 ; rm -rf fremovexattr.2.gz )
( cd usr/man/man2 ; ln -sf removexattr.2.gz fremovexattr.2.gz )
( cd usr/man/man3 ; rm -rf attr_list_by_handle.3.gz )
( cd usr/man/man3 ; ln -sf path_to_handle.3.gz attr_list_by_handle.3.gz )
( cd usr/man/man3 ; rm -rf path_to_fshandle.3.gz )
( cd usr/man/man3 ; ln -sf path_to_handle.3.gz path_to_fshandle.3.gz )
( cd usr/man/man3 ; rm -rf attr_multif.3.gz )
( cd usr/man/man3 ; ln -sf attr_multi.3.gz attr_multif.3.gz )
( cd usr/man/man3 ; rm -rf attr_setf.3.gz )
( cd usr/man/man3 ; ln -sf attr_set.3.gz attr_setf.3.gz )
( cd usr/man/man3 ; rm -rf attr_getf.3.gz )
( cd usr/man/man3 ; ln -sf attr_get.3.gz attr_getf.3.gz )
( cd usr/man/man3 ; rm -rf readlink_by_handle.3.gz )
( cd usr/man/man3 ; ln -sf path_to_handle.3.gz readlink_by_handle.3.gz )
( cd usr/man/man3 ; rm -rf fssetdm_by_handle.3.gz )
( cd usr/man/man3 ; ln -sf path_to_handle.3.gz fssetdm_by_handle.3.gz )
( cd usr/man/man3 ; rm -rf attr_multi_by_handle.3.gz )
( cd usr/man/man3 ; ln -sf path_to_handle.3.gz attr_multi_by_handle.3.gz )
( cd usr/man/man3 ; rm -rf free_handle.3.gz )
( cd usr/man/man3 ; ln -sf path_to_handle.3.gz free_handle.3.gz )
( cd usr/man/man8 ; rm -rf xfs_info.8.gz )
( cd usr/man/man8 ; ln -sf xfs_growfs.8.gz xfs_info.8.gz )
( cd usr/man/man8 ; rm -rf xfsrq.8.gz )
( cd usr/man/man8 ; ln -sf xfsdq.8.gz xfsrq.8.gz )
( cd usr/sbin ; rm -rf xfsrestore )
( cd usr/sbin ; ln -sf /sbin/xfsrestore xfsrestore )
( cd usr/sbin ; rm -rf xfsdump )
( cd usr/sbin ; ln -sf /sbin/xfsdump xfsdump )

==> xfsprogs-2.8.10_1-i486-1.tgz: install/doinst.sh <==
( cd lib ; rm -rf libhandle.so.1 )
( cd lib ; ln -sf libhandle.so.1.0.3 libhandle.so.1 )
( cd usr/lib ; rm -rf libhandle.so )
( cd usr/lib ; ln -sf /lib/libhandle.so.1 libhandle.so )
( cd usr/man/man3 ; rm -rf attr_list_by_handle.3.gz )
( cd usr/man/man3 ; ln -sf path_to_handle.3.gz attr_list_by_handle.3.gz )
( cd usr/man/man3 ; rm -rf path_to_fshandle.3.gz )
( cd usr/man/man3 ; ln -sf path_to_handle.3.gz path_to_fshandle.3.gz )
( cd usr/man/man3 ; rm -rf handle_to_fshandle.3.gz )
( cd usr/man/man3 ; ln -sf path_to_handle.3.gz handle_to_fshandle.3.gz )
( cd usr/man/man3 ; rm -rf fd_to_handle.3.gz )
( cd usr/man/man3 ; ln -sf path_to_handle.3.gz fd_to_handle.3.gz )
( cd usr/man/man3 ; rm -rf getparents_by_handle.3.gz )
( cd usr/man/man3 ; ln -sf path_to_handle.3.gz getparents_by_handle.3.gz )
( cd usr/man/man3 ; rm -rf readlink_by_handle.3.gz )
( cd usr/man/man3 ; ln -sf path_to_handle.3.gz readlink_by_handle.3.gz )
( cd usr/man/man3 ; rm -rf fssetdm_by_handle.3.gz )
( cd usr/man/man3 ; ln -sf path_to_handle.3.gz fssetdm_by_handle.3.gz )
( cd usr/man/man3 ; rm -rf open_by_handle.3.gz )
( cd usr/man/man3 ; ln -sf path_to_handle.3.gz open_by_handle.3.gz )
( cd usr/man/man3 ; rm -rf attr_multi_by_handle.3.gz )
( cd usr/man/man3 ; ln -sf path_to_handle.3.gz attr_multi_by_handle.3.gz )
( cd usr/man/man3 ; rm -rf getparentpaths_by_handle.3.gz )
( cd usr/man/man3 ; ln -sf path_to_handle.3.gz getparentpaths_by_handle.3.gz )
( cd usr/man/man3 ; rm -rf free_handle.3.gz )
( cd usr/man/man3 ; ln -sf path_to_handle.3.gz free_handle.3.gz )
( cd usr/man/man8 ; rm -rf xfs_info.8.gz )
( cd usr/man/man8 ; ln -sf xfs_growfs.8.gz xfs_info.8.gz )
